
:: Python 2 tests are passing correctly but erroring probably because of PyQt 5.6
if %PYTHON_VERSION% == 2.7 (
    python runtests.py || exit 0
) else (
    python runtests.py || python runtests.py || python runtests.py || exit 1
)

:: Run codecov if things were successful
codecov
